@@ -23,6 +23,9 @@ int demo(char *a, char *b) {
  scanf("%10s", s);
  scanf("%s", s);
  gets(f); // Flawfinder: ignore
+ printf("\\");
+ /* Flawfinder: ignore */
+ gets(f);
  gets(f);
 }
 
